@@ -24,7 +24,7 @@ class CaptchaOperDataInterceptUnit(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param DateKey: 时间
         :type DateKey: str
         :param AllStopCnt: 停止验证数量
@@ -60,7 +60,7 @@ class CaptchaOperDataLoadTimeUnit(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param DateKey: 时间
         :type DateKey: str
         :param MarketLoadTime: Market加载时间
@@ -92,7 +92,7 @@ class CaptchaOperDataRes(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param OperDataLoadTimeUnitArray: 验证码加载耗时数据返回
 注意：此字段可能返回 null，表示取不到有效值。
         :type OperDataLoadTimeUnitArray: list of CaptchaOperDataLoadTimeUnit
@@ -152,7 +152,7 @@ class CaptchaOperDataTryTimesDistributeUnit(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param TryCount: 尝试次数
         :type TryCount: int
         :param UserCount: 用户请求数量
@@ -180,7 +180,7 @@ class CaptchaOperDataTryTimesUnit(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param DateKey: 时间
         :type DateKey: str
         :param CntPerPass: 平均尝试次数
@@ -212,7 +212,7 @@ class CaptchaQueryData(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Cnt: 数量
         :type Cnt: int
         :param Date: 时间
@@ -240,7 +240,7 @@ class CaptchaTicketDataRes(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param TicketAmountArray: 票据验证总量返回
         :type TicketAmountArray: list of TicketAmountUnit
         :param TicketThroughArray: 票据验证通过量返回
@@ -287,7 +287,7 @@ class CaptchaUserAllAppId(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param CaptchaAppId: 验证码应用ID
         :type CaptchaAppId: int
         :param AppName: 注册应用名称
@@ -323,7 +323,7 @@ class DescribeCaptchaAppIdInfoRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param CaptchaAppId: 验证码应用注册APPID
         :type CaptchaAppId: int
         """
@@ -347,7 +347,7 @@ class DescribeCaptchaAppIdInfoResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param SchemeColor: 界面风格
         :type SchemeColor: str
         :param Language: 语言
@@ -426,7 +426,7 @@ class DescribeCaptchaDataRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param CaptchaAppId: 验证码应用ID
         :type CaptchaAppId: int
         :param Start: 查询开始时间
@@ -462,7 +462,7 @@ class DescribeCaptchaDataResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param CaptchaCode: 返回码 0 成功 其它失败
         :type CaptchaCode: int
         :param Data: 数据数组
@@ -498,7 +498,7 @@ class DescribeCaptchaDataSumRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param CaptchaAppId: 验证码应用ID
         :type CaptchaAppId: int
         :param Start: 查询开始时间
@@ -530,7 +530,7 @@ class DescribeCaptchaDataSumResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param GetSum: 请求总量
         :type GetSum: int
         :param VfySuccSum: 请求验证成功量
@@ -576,7 +576,7 @@ class DescribeCaptchaMiniDataRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param CaptchaAppId: 验证码应用ID
         :type CaptchaAppId: int
         :param Start: 查询开始时间 例如：2019112900
@@ -612,7 +612,7 @@ class DescribeCaptchaMiniDataResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param CaptchaCode: 返回码 0 成功 其它失败
         :type CaptchaCode: int
         :param Data: 数据数组
@@ -648,7 +648,7 @@ class DescribeCaptchaMiniDataSumRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param CaptchaAppId: 验证码应用ID
         :type CaptchaAppId: int
         :param Start: 查询开始时间
@@ -680,7 +680,7 @@ class DescribeCaptchaMiniDataSumResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param GetSum: 请求总量
 注意：此字段可能返回 null，表示取不到有效值。
         :type GetSum: int
@@ -742,23 +742,27 @@ class DescribeCaptchaMiniOperDataRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param CaptchaAppId: 验证码应用ID
         :type CaptchaAppId: int
         :param Start: 查询开始时间
         :type Start: int
         :param Type: 查询类型
         :type Type: int
+        :param End: 查询结束时间
+        :type End: int
         """
         self.CaptchaAppId = None
         self.Start = None
         self.Type = None
+        self.End = None
 
 
     def _deserialize(self, params):
         self.CaptchaAppId = params.get("CaptchaAppId")
         self.Start = params.get("Start")
         self.Type = params.get("Type")
+        self.End = params.get("End")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -774,7 +778,7 @@ class DescribeCaptchaMiniOperDataResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param CaptchaCode: 成功返回 0 其它失败
         :type CaptchaCode: int
         :param CaptchaMsg: 返回信息
@@ -807,16 +811,16 @@ class DescribeCaptchaMiniResultRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param CaptchaType: 固定填值：9（滑块验证码）
         :type CaptchaType: int
         :param Ticket: 验证码返回给用户的票据
         :type Ticket: str
-        :param UserIp: 透传业务侧获取到的验证码使用者的IP
+        :param UserIp: 业务侧获取到的验证码使用者的外网IP
         :type UserIp: str
-        :param CaptchaAppId: 验证码应用APPID
+        :param CaptchaAppId: 验证码应用ID。登录 [验证码控制台](https://console.cloud.tencent.com/captcha/graphical)，在验证列表的【密钥】列，即可查看到CaptchaAppId。
         :type CaptchaAppId: int
-        :param AppSecretKey: 用于服务器端校验验证码票据的验证密钥，请妥善保密，请勿泄露给第三方
+        :param AppSecretKey: 验证码应用密钥。登录 [验证码控制台](https://console.cloud.tencent.com/captcha/graphical)，在验证列表的【密钥】列，即可查看到AppSecretKey。AppSecretKey属于服务器端校验验证码票据的密钥，请妥善保密，请勿泄露给第三方。
         :type AppSecretKey: str
         :param BusinessId: 业务 ID，网站或应用在多个业务中使用此服务，通过此 ID 区分统计数据
         :type BusinessId: int
@@ -863,7 +867,7 @@ class DescribeCaptchaMiniResultResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param CaptchaCode: 1       ticket verification succeeded     票据验证成功
 7       CaptchaAppId does not match     票据与验证码应用APPID不匹配
 8       ticket expired     票据超时
@@ -871,6 +875,7 @@ class DescribeCaptchaMiniResultResponse(AbstractModel):
 15     ticket decryption failed     票据解密失败
 16     CaptchaAppId wrong format     检查验证码应用APPID错误
 21     ticket error     票据验证错误
+25     invalid ticket     无效票据
 26     system internal error     系统内部错误
 100   param err     参数校验错误
         :type CaptchaCode: int
@@ -897,12 +902,12 @@ class DescribeCaptchaMiniRiskResultRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param CaptchaType: 固定填值：9（滑块验证码）
         :type CaptchaType: int
         :param Ticket: 验证码返回给用户的票据
         :type Ticket: str
-        :param UserIp: 用户操作来源的外网 IP
+        :param UserIp: 业务侧获取到的验证码使用者的外网IP
         :type UserIp: str
         :param CaptchaAppId: 验证码应用APPID
         :type CaptchaAppId: int
@@ -961,7 +966,7 @@ class DescribeCaptchaMiniRiskResultResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param CaptchaCode: 1 ticket verification succeeded 票据验证成功
 7 CaptchaAppId does not match 票据与验证码应用APPID不匹配
 8 ticket expired 票据超时
@@ -1005,23 +1010,27 @@ class DescribeCaptchaOperDataRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param CaptchaAppId: 验证码应用ID
         :type CaptchaAppId: int
         :param Start: 查询开始时间
         :type Start: int
         :param Type: 查询类型
         :type Type: int
+        :param End: 查询结束时间
+        :type End: int
         """
         self.CaptchaAppId = None
         self.Start = None
         self.Type = None
+        self.End = None
 
 
     def _deserialize(self, params):
         self.CaptchaAppId = params.get("CaptchaAppId")
         self.Start = params.get("Start")
         self.Type = params.get("Type")
+        self.End = params.get("End")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -1037,7 +1046,7 @@ class DescribeCaptchaOperDataResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param CaptchaCode: 成功返回 0 其它失败
         :type CaptchaCode: int
         :param CaptchaMsg: 返回信息
@@ -1070,18 +1079,18 @@ class DescribeCaptchaResultRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param CaptchaType: 固定填值：9。可在控制台配置不同验证码类型。
         :type CaptchaType: int
         :param Ticket: 前端回调函数返回的用户验证票据
         :type Ticket: str
-        :param UserIp: 透传业务侧获取到的验证码使用者的IP
+        :param UserIp: 业务侧获取到的验证码使用者的外网IP
         :type UserIp: str
         :param Randstr: 前端回调函数返回的随机字符串
         :type Randstr: str
-        :param CaptchaAppId: 验证码应用ID
+        :param CaptchaAppId: 验证码应用ID。登录 [验证码控制台](https://console.cloud.tencent.com/captcha/graphical)，在验证列表的【密钥】列，即可查看到CaptchaAppId。
         :type CaptchaAppId: int
-        :param AppSecretKey: 用于服务器端校验验证码票据的验证密钥，请妥善保密，请勿泄露给第三方
+        :param AppSecretKey: 验证码应用密钥。登录 [验证码控制台](https://console.cloud.tencent.com/captcha/graphical)，在验证列表的【密钥】列，即可查看到AppSecretKey。AppSecretKey属于服务器端校验验证码票据的密钥，请妥善保密，请勿泄露给第三方。
         :type AppSecretKey: str
         :param BusinessId: 业务 ID，网站或应用在多个业务中使用此服务，通过此 ID 区分统计数据
         :type BusinessId: int
@@ -1134,7 +1143,7 @@ class DescribeCaptchaResultResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param CaptchaCode: 1 OK 验证通过
 6 user code len error 验证码长度不匹配，请检查请求是否带Randstr参数，Randstr参数大小写是否有误
 7 captcha no match 验证码答案不匹配/Randstr参数不匹配，请重新生成Randstr、Ticket进行校验
@@ -1145,24 +1154,28 @@ class DescribeCaptchaResultResponse(AbstractModel):
 12 sig len error 签名长度错误
 13 verify ip no match ip不匹配，非法请求，可能存在不规范接入
 15 decrypt fail 验证码签名解密失败，票据校验失败，请检查Ticket票据是否与前端返回Ticket一致
-16 appid no match 验证码强校验appid错误，请检查CaptchaAppId是否为控制台基础配置界面系统分配的APPID
+16 appid no match 验证码强校验appid错误，前端代码 data-appid 和后端 CaptchaAppId 所填写的值，必须和 验证码控制台 中【验证详情】>【基础配置】内的 AppID 一致,请检查CaptchaAppId是否为控制台基础配置界面系统分配的APPID
 17 cmd no much 验证码系统命令不匹配
 18 uin no match 号码不匹配
 19 seq redirect 重定向验证
 20 opt no vcode 操作使用pt免验证码校验错误
-21 diff 差别，验证错误
+21 diff 差别，验证错误 
+该情况出现原因一般为，当验证码前端生成terror格式票据并进行后端票据校验时，用户网络较差，该情况下仍会返回可用票据，业务侧可以自行根据需要，进行票据生成或做其他处理。详情参见 [验证码Web前端接入-异常处理文档](https://cloud.tencent.com/document/product/1110/36841#.E5.BC.82.E5.B8.B8.E5.A4.84.E7.90.86)。
 22 captcha type not match 验证码类型与拉取时不一致
 23 verify type error 验证类型错误
 24 invalid pkg 非法请求包
 25 bad visitor 策略拦截
 26 system busy 系统内部错误
-100 param err appsecretkey 参数校验错误，请检查AppSecretKey是否与控制台基础配置界面系统分配的APPID、AppSecretKey相对应
+100 param err appsecretkey 参数校验错误，CaptchaAppId 与对应 AppSecretKey 不一致，需检查 AppSecretKey 参数是否有误。其中 CaptchaAppId、 AppSecretKey 在 验证码控制台 的【验证详情】>【基础配置】中获取
 104 Ticket Reuse 票据重复使用，同个票据验证多次，请重新生成Randstr、Ticket进行校验
         :type CaptchaCode: int
         :param CaptchaMsg: 状态描述及验证错误信息
 注意：此字段可能返回 null，表示取不到有效值。
         :type CaptchaMsg: str
-        :param EvilLevel: [0,100]，恶意等级
+        :param EvilLevel: 无感验证模式下，该参数返回验证结果：
+
+EvilLevel=0 请求无恶意
+EvilLevel=100 请求有恶意
 注意：此字段可能返回 null，表示取不到有效值。
         :type EvilLevel: int
         :param GetCaptchaTime: 前端获取验证码时间，时间戳格式
@@ -1192,19 +1205,23 @@ class DescribeCaptchaTicketDataRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param CaptchaAppId: 验证码应用ID
         :type CaptchaAppId: int
         :param Start: 查询开始时间 例如：20200909
         :type Start: int
+        :param End: 查询结束时间 例如：20220314
+        :type End: int
         """
         self.CaptchaAppId = None
         self.Start = None
+        self.End = None
 
 
     def _deserialize(self, params):
         self.CaptchaAppId = params.get("CaptchaAppId")
         self.Start = params.get("Start")
+        self.End = params.get("End")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -1220,7 +1237,7 @@ class DescribeCaptchaTicketDataResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param CaptchaCode: 成功返回 0 其它失败
         :type CaptchaCode: int
         :param CaptchaMsg: 返回信息
@@ -1259,7 +1276,7 @@ class DescribeCaptchaUserAllAppIdResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Data: 用户注册的所有Appid和应用名称
 注意：此字段可能返回 null，表示取不到有效值。
         :type Data: list of CaptchaUserAllAppId
@@ -1295,7 +1312,7 @@ class OutputManageMarketingRiskValue(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param UserId: 账号 ID。对应输入参数： AccountType 是 1 时，对应 QQ 的 OpenID。
 AccountType 是 2 时，对应微信的 OpenID/UnionID。
 AccountType 是 4 时，对应手机号。
@@ -1376,7 +1393,7 @@ class TicketAmountUnit(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param DateKey: 时间
         :type DateKey: str
         :param Amount: 票据验证总量
@@ -1404,7 +1421,7 @@ class TicketInterceptUnit(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param DateKey: 时间
         :type DateKey: str
         :param Intercept: 票据验证拦截量
@@ -1432,7 +1449,7 @@ class TicketThroughUnit(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param DateKey: 时间
         :type DateKey: str
         :param Through: 票据验证的通过量
@@ -1460,7 +1477,7 @@ class UpdateCaptchaAppIdInfoRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param CaptchaAppId: 验证码应用ID
         :type CaptchaAppId: int
         :param AppName: 应用名
@@ -1532,7 +1549,7 @@ class UpdateCaptchaAppIdInfoResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param CaptchaCode: 返回码 0 成功，其它失败
         :type CaptchaCode: int
         :param CaptchaMsg: 返回操作信息
